Stressor Monitor

# Stressor Monitor ready

Auto-refresh: off fast

Scenario: n.a. Tag: n.a. Started: n.a. Ended: n.a. Base URL: n.a.

## Run Status ( 0 sessions )

Sequence | Sequences | Activities | Net Activities
--- | --- | --- | ---
Iterations | Σ | Ø | Max. | Count | Errors | Count | Σ | Ø | Max. | 1/sec

## Monitored Activities

Activity | Count | Errors | Σ | Min. | Ø | Max. | Last Error
--- | --- | --- | --- | --- | --- | --- | ---

## 0 Sessions ( 0 running )

# | ID | User | Sequences | Activities | Errors | Current Path
--- | --- | --- | --- | --- | --- | ---

Stressor © 2020 Martin Wendt